@@ -1,8 +1,8 @@
 package Perinci::Sub::ValidateArgs;
 
 # NOIFBUILT
-our $DATE = '2016-05-25'; # DATE
-our $VERSION = '0.008'; # VERSION
+our $DATE = '2016-05-26'; # DATE
+our $VERSION = '0.009'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -152,7 +152,7 @@ sub gen_args_validator {
             push @code, "    if (\@\$args >= $pos) { \$args->[$pos] = [splice \@\$args, $pos] }\n\n";
         }
         push @code, "    # check extraneous args\n";
-        push @code, "    if (\@\$args > ".(@arg_names).") { ".$gencode_err->(400, "\"Too many arguments (expected ".(@arg_names).", got \".(\@\$args)") . " }\n";
+        push @code, "    if (\@\$args > ".(@arg_names).") { ".$gencode_err->(400, "\"Too many arguments (expected ".(@arg_names).", got \".(\@\$args).\")\"") . " }\n";
         push @code, "\n";
 
         for my $i (0..$#arg_names) {
@@ -213,7 +213,7 @@ Perinci::Sub::ValidateArgs - Validate function arguments using schemas in Rinci
 
 =head1 VERSION
 
-This document describes version 0.008 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-25.
+This document describes version 0.009 of Perinci::Sub::ValidateArgs (from Perl distribution Perinci-Sub-ValidateArgs), released on 2016-05-26.
 
 =head1 SYNOPSIS
 
